stats Package — cobra 0.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- cobra 0.2.0 documentation »
- cobra Package »

# stats Package

## `stats` Package

## `stats` Module

`cobra.stats.stats.` `combine_p_values`(the_p_values, method='z', default_quantile=7.0)

  Combines p-values from repeat measurements into a single p-value.

  the_p_values: a list of p-values.

  method: String. ‘z’|’fisher’. ‘z’ for using the weighted z-score. ‘fisher’ for using fisher’s combined probability test.

  default_quantile: Float. Only used for z method. The quantile to use when the software’s normal inverse cdf(p-value) is infinite

`cobra.stats.stats.` `error_weighted`(the_means, the_stds)

  Calculate the error-weighted mean and standard deviation.

  the_means: A list or numpy array of floats.

  the_stds: A list or numpy array of floats.

`cobra.stats.stats.` `p_adjust`(the_p_values, correction_method='bh')

  Adjusts the p-values in a list for multiple hypothesis testing.

  the_p_values: a list of p-values

  correction_method: String. ‘bh’|’by’|’bonferroni’. ‘bh’ for Benjamini & Hochberg, ‘by’ for Benjamini & Yekuieli, and ‘bonferroni’ for Bonferroni.

  NOTE: ‘bh’ and ‘by’ require R and rpy2 installed

### Navigation

- index
- modules |
- next |
- previous |
- cobra 0.2.0 documentation »
- cobra Package »